Documentation
¶
Overview ¶
Package mocks contains generated mock implementations for testing.
Each mock file corresponds to exactly one source package to satisfy the mockgen constraint that all mocks in an output file come from the same source package.
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.
Index ¶
- type MockManager
- func (m *MockManager) CreateGuardian(ctx context.Context, name, certThumbprint string) (*guardian.Guardian, error)
- func (m *MockManager) DeleteGuardian(ctx context.Context, name string) error
- func (m *MockManager) EXPECT() *MockManagerMockRecorder
- func (m *MockManager) GetGuardian(ctx context.Context, name string) (*guardian.Guardian, error)
- func (m *MockManager) ListHosts(ctx context.Context, guardianName string) ([]string, error)
- func (m *MockManager) RegisterHost(ctx context.Context, reg guardian.HostRegistration) error
- func (m *MockManager) UnregisterHost(ctx context.Context, hostName string) error
- type MockManagerMockRecorder
- func (mr *MockManagerMockRecorder) CreateGuardian(ctx, name, certThumbprint any) *gomock.Call
- func (mr *MockManagerMockRecorder) DeleteGuardian(ctx, name any) *gomock.Call
- func (mr *MockManagerMockRecorder) GetGuardian(ctx, name any) *gomock.Call
- func (mr *MockManagerMockRecorder) ListHosts(ctx, guardianName any) *gomock.Call
- func (mr *MockManagerMockRecorder) RegisterHost(ctx, reg any) *gomock.Call
- func (mr *MockManagerMockRecorder) UnregisterHost(ctx, hostName any) *gomock.Call
- type MockVerifier
- func (m *MockVerifier) Attest(ctx context.Context, guardianName string, state attestation.PlatformState) (*attestation.AttestationResult, error)
- func (m *MockVerifier) EXPECT() *MockVerifierMockRecorder
- func (m *MockVerifier) GetCertificate(ctx context.Context, vmID string) (*attestation.HealthCertificate, error)
- func (m *MockVerifier) RevokeCertificate(ctx context.Context, vmID string) error
- type MockVerifierMockRecorder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockManager ¶
type MockManager struct {
// contains filtered or unexported fields
}
MockManager is a mock of Manager interface.
func NewMockManager ¶
func NewMockManager(ctrl *gomock.Controller) *MockManager
NewMockManager creates a new mock instance.
func (*MockManager) CreateGuardian ¶
func (m *MockManager) CreateGuardian(ctx context.Context, name, certThumbprint string) (*guardian.Guardian, error)
CreateGuardian mocks base method.
func (*MockManager) DeleteGuardian ¶
func (m *MockManager) DeleteGuardian(ctx context.Context, name string) error
DeleteGuardian mocks base method.
func (*MockManager) EXPECT ¶
func (m *MockManager) EXPECT() *MockManagerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockManager) GetGuardian ¶
GetGuardian mocks base method.
func (*MockManager) RegisterHost ¶
func (m *MockManager) RegisterHost(ctx context.Context, reg guardian.HostRegistration) error
RegisterHost mocks base method.
func (*MockManager) UnregisterHost ¶
func (m *MockManager) UnregisterHost(ctx context.Context, hostName string) error
UnregisterHost mocks base method.
type MockManagerMockRecorder ¶
type MockManagerMockRecorder struct {
// contains filtered or unexported fields
}
MockManagerMockRecorder is the mock recorder for MockManager.
func (*MockManagerMockRecorder) CreateGuardian ¶
func (mr *MockManagerMockRecorder) CreateGuardian(ctx, name, certThumbprint any) *gomock.Call
CreateGuardian indicates an expected call of CreateGuardian.
func (*MockManagerMockRecorder) DeleteGuardian ¶
func (mr *MockManagerMockRecorder) DeleteGuardian(ctx, name any) *gomock.Call
DeleteGuardian indicates an expected call of DeleteGuardian.
func (*MockManagerMockRecorder) GetGuardian ¶
func (mr *MockManagerMockRecorder) GetGuardian(ctx, name any) *gomock.Call
GetGuardian indicates an expected call of GetGuardian.
func (*MockManagerMockRecorder) ListHosts ¶
func (mr *MockManagerMockRecorder) ListHosts(ctx, guardianName any) *gomock.Call
ListHosts indicates an expected call of ListHosts.
func (*MockManagerMockRecorder) RegisterHost ¶
func (mr *MockManagerMockRecorder) RegisterHost(ctx, reg any) *gomock.Call
RegisterHost indicates an expected call of RegisterHost.
func (*MockManagerMockRecorder) UnregisterHost ¶
func (mr *MockManagerMockRecorder) UnregisterHost(ctx, hostName any) *gomock.Call
UnregisterHost indicates an expected call of UnregisterHost.
type MockVerifier ¶
type MockVerifier struct {
// contains filtered or unexported fields
}
MockVerifier is a mock of Verifier interface.
func NewMockVerifier ¶
func NewMockVerifier(ctrl *gomock.Controller) *MockVerifier
NewMockVerifier creates a new mock instance.
func (*MockVerifier) Attest ¶
func (m *MockVerifier) Attest(ctx context.Context, guardianName string, state attestation.PlatformState) (*attestation.AttestationResult, error)
Attest mocks base method.
func (*MockVerifier) EXPECT ¶
func (m *MockVerifier) EXPECT() *MockVerifierMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockVerifier) GetCertificate ¶
func (m *MockVerifier) GetCertificate(ctx context.Context, vmID string) (*attestation.HealthCertificate, error)
GetCertificate mocks base method.
func (*MockVerifier) RevokeCertificate ¶
func (m *MockVerifier) RevokeCertificate(ctx context.Context, vmID string) error
RevokeCertificate mocks base method.
type MockVerifierMockRecorder ¶
type MockVerifierMockRecorder struct {
// contains filtered or unexported fields
}
MockVerifierMockRecorder is the mock recorder for MockVerifier.
func (*MockVerifierMockRecorder) Attest ¶
func (mr *MockVerifierMockRecorder) Attest(ctx, guardianName, state any) *gomock.Call
Attest indicates an expected call of Attest.
func (*MockVerifierMockRecorder) GetCertificate ¶
func (mr *MockVerifierMockRecorder) GetCertificate(ctx, vmID any) *gomock.Call
GetCertificate indicates an expected call of GetCertificate.
func (*MockVerifierMockRecorder) RevokeCertificate ¶
func (mr *MockVerifierMockRecorder) RevokeCertificate(ctx, vmID any) *gomock.Call
RevokeCertificate indicates an expected call of RevokeCertificate.